summaryrefslogtreecommitdiffstats
path: root/source/Generating/DistortedHeightmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/Generating/DistortedHeightmap.h')
-rw-r--r--source/Generating/DistortedHeightmap.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/source/Generating/DistortedHeightmap.h b/source/Generating/DistortedHeightmap.h
index 65ec70a6d..83c638ce8 100644
--- a/source/Generating/DistortedHeightmap.h
+++ b/source/Generating/DistortedHeightmap.h
@@ -53,7 +53,8 @@ protected:
NOISE_DATATYPE * m_NoiseArrayZ;
cBiomeGen & m_BiomeGen;
- cHeiGenCache m_HeightGen; // This generator provides us with base heightmap (before distortion)
+ cHeiGenBiomal m_UnderlyingHeiGen; // This generator provides us with base heightmap (before distortion)
+ cHeiGenCache m_HeightGen; // Cache above m_UnderlyingHeiGen
/// Heightmap for the current chunk, before distortion (from m_HeightGen). Used for optimization.
cChunkDef::HeightMap m_CurChunkHeights;